==> rescope-1.7.6.tgz: package/src/example/react/NewsListComp.js <==
/*
 * Copyright (c)  2017 Caipi Labs .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

'use strict';

import React from "react";
import {Store} from "../../Rescope";

export default class NewsListComp extends React.Component {

    constructor( ) {
        super(...arguments);
        this.state = {
            ...Store.map(this, ["userEvents"])
        };

    }

    render() {
        return (
            <div className="NewsListComp container" style={{minHeight : "100%"}}>
                <h1>Mes events</h1>
                {
                    this.state.userEvents &&
                    this.state.userEvents.events.map(
                        ( evt, i ) =>
                            <div style={{border : "solid 1px lightgrey", borderRadius : "3px"}} key={i}>
                                <b><u>
                                    <center>Event type : {evt.type}</center>
                                </u></b>
                                <p>{evt.text}</p>
                            </div>
                    )
                }

            </div>
        );
    }
};

==> rescope-2.0.1.tgz: package/src/example/react/NewsListComp.js <==
/*
 * Copyright (c)  2017 Caipi Labs .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

'use strict';

import React from "react";
import {Context} from "../../Rescope";

export default class NewsListComp extends React.Component {

    constructor( ) {
        super(...arguments);
        this.state = {
            ...Context.contexts.appContext.pull(this, ["userEvents"])
        };

    }

    render() {
        return (
            <div className="NewsListComp container" style={{minHeight : "100%"}}>
                <h1>Mes events</h1>
                {
                    this.state.userEvents &&
                    this.state.userEvents.events.map(
                        ( evt, i ) =>
                            <div style={{border : "solid 1px lightgrey", borderRadius : "3px"}} key={i}>
                                <b><u>
                                    <center>Event type : {evt.type}</center>
                                </u></b>
                                <p>{evt.text}</p>
                            </div>
                    )
                }

            </div>
        );
    }
};
